#include <Wire.h>
#include <SPI.h>
#include <Adafruit_GFX.h>
#include <Adafruit_ST7735.h> 
#include <Keypad.h>
#include "si5351.h"

Si5351 si5351;
String frq_str = "";

#define sclk 13
#define mosi 11
#define cs   16
#define dc   14
#define rst  15  

Adafruit_ST7735 tft = Adafruit_ST7735(cs, dc, rst);

const byte numRows= 4; //number of rows on the keypad
const byte numCols= 4; //number of columns on the keypad

char keymap[numRows][numCols]= 
{
{'1', '2', '3', 'A'}, 
{'4', '5', '6', 'B'}, 
{'7', '8', '9', 'C'},
{'*', '0', '#', 'D'}
};

byte rowPins[numRows] = {9,8,7,6}; //Rows 0 to 3 ( 4x4 Pin 1-4 )
byte colPins[numCols]= {5,4,3,2}; //Columns 0 to 3 ( 4x4 Pin 5-8 )

Keypad myKeypad= Keypad(makeKeymap(keymap), rowPins, colPins, numRows, numCols);

//////////////////////////////////////////////////////////////
void setup()   {                
  Serial.begin(9600);

// Start serial and initialize the Si5351
  si5351.init(SI5351_CRYSTAL_LOAD_8PF);
  si5351.set_pll(SI5351_PLL_FIXED, SI5351_PLLA);
  si5351.set_freq(frq_str.toInt(), SI5351_PLL_FIXED, SI5351_CLK0);

  Serial.println("Start");
  tft.initR(INITR_BLACKTAB);   
  tft.setRotation(tft.getRotation() + 1); // rotate 90degs
  tft.fillScreen(ST7735_BLACK);
  tft.setTextSize(2);    
  tft.setTextColor(ST7735_YELLOW);
  tft.setCursor(50, 20);
  tft.print("Si5351") ; 
  tft.setCursor(30, 40);
  tft.print("GENERATOR") ; 
  tft.setTextSize(1);    
  tft.setTextColor(ST7735_WHITE);
  tft.setCursor(40, 100);
  tft.print("(C) DJ7OO 2014") ; 
  delay(3000);  
  tft.fillScreen(ST7735_BLACK);
  tft.setTextSize(2);    
  tft.setCursor(10, 10);
  tft.print("Enter Frq");
  tft.setCursor(10, 30);
  tft.print("in Hz:");
  tft.setCursor(10, 55);
}

////////////////////////////////////////////////////////////////
void loop() {  
char keypressed = myKeypad.getKey();
if (keypressed != NO_KEY)
{
  if(keypressed=='*')  
{  tft.fillScreen(ST7735_BLACK);
   tft.setTextSize(2);    
   tft.setTextColor(ST7735_WHITE);
   tft.setCursor(10, 10);
   tft.print("ENTER FRQ");
   tft.setCursor(10, 30);
   tft.print("IN HZ:");
   tft.setCursor(10, 55); 
   frq_str="";
} 

 else if(keypressed=='#')  
{  tft.setTextSize(2);    
   tft.setTextColor(ST7735_WHITE);
   tft.setCursor(35, 90);
   tft.print("EXECUTED");
   tft.setCursor(10, 55);  
   call_frq(); 
   frq_str="";
}
  else  
{ Serial.println(keypressed);
  tft.setTextSize(3);    
  tft.setTextColor(ST7735_YELLOW);
  frq_str += keypressed;  
  tft.print(keypressed) ; }
 }
}

/////////////////////////////////////////////////////////
void call_frq() {
  Serial.println(frq_str);
  si5351.set_pll(SI5351_PLL_FIXED, SI5351_PLLA);
  si5351.set_freq(frq_str.toInt(), SI5351_PLL_FIXED, SI5351_CLK0);
}


